from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .Interaction import Interaction


@abaqus_class_doc
class ContactMassScalingExp(Interaction):
    """TThe ContactMassScalingExp object defines contact mass scaling during an Abaqus/Explicit analysis. The
    ContactMassScalingExp object is derived from the Interaction object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

    .. versionadded:: 2024

        The ``ContactMassScalingExp`` class was added.
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the ContactMassScalingExp object is
    #: created.
    createStepName: str

    #: A SymbolicConstant specifying the location. Possible values are ELEMENT MASS SCALING
    #: (default), NONE, ALL CONTACT SURFACES, and SPECIFIED SURFACES.
    location: SymbolicConstant

    #: A tuple of Region objects specifying the surfaces when LOCATION=SPECIFIED SURFACES.
    surfaces: tuple[Region]

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        location: Literal[
            C.ELEMENT_MASS_SCALING, C.NONE, C.ALL_CONTACT_SURFACES, C.SPECIFIED_SURFACES
        ] = C.ELEMENT_MASS_SCALING,
        surfaces: tuple = (),
    ):
        """This method creates an ContactMassScalingExp object.

        .. note::
            This function can be accessed by::

                mdb.models[name].ContactMassScalingExp

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the ContactMassScalingExp object is created.
        location
            A SymbolicConstant specifying the location. Possible values are ELEMENT MASS SCALING (default), NONE,
            ALL CONTACT SURFACES, and SPECIFIED SURFACES.
        surfaces
            A tuple of Region objects specifying the surfaces when LOCATION=SPECIFIED SURFACES.

        Returns
        -------
        ContactMassScalingExp
            An ContactMassScalingExp object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        location: Literal[
            C.ELEMENT_MASS_SCALING, C.NONE, C.ALL_CONTACT_SURFACES, C.SPECIFIED_SURFACES
        ] = C.ELEMENT_MASS_SCALING,
        surfaces: tuple = (),
    ):
        """This method modifies the data for an existing ContactMassScalingExp object in the step where it is
        created.

        Parameters
        ----------
        location
            A SymbolicConstant specifying the location. Possible values are ELEMENT MASS SCALING (default), NONE,
            ALL CONTACT SURFACES, and SPECIFIED SURFACES.
        surfaces
            A tuple of Region objects specifying the surfaces when LOCATION=SPECIFIED SURFACES.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        location: Literal[
            C.ELEMENT_MASS_SCALING, C.NONE, C.ALL_CONTACT_SURFACES, C.SPECIFIED_SURFACES
        ] = C.ELEMENT_MASS_SCALING,
        surfaces: tuple = (),
    ):
        """This method modifies the propagating data for an existing ContactMassScalingExp object in the specified
        step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        location
            A SymbolicConstant specifying the location. Possible values are ELEMENT MASS SCALING (default), NONE,
            ALL CONTACT SURFACES, and SPECIFIED SURFACES.
        surfaces
            A tuple of Region objects specifying the surfaces when LOCATION=SPECIFIED SURFACES.
        """
        ...



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import DEFAULT_MODEL, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .Leaf import Leaf


@abaqus_class_doc
class LeafFromConstraintNames(Leaf):
    """The LeafFromConstraintNames object can be used whenever a Leaf object is expected as an argument. A Leaf
    object is used used to specify the items in a display group. Leaf objects are constructed as temporary
    objects that are used as arguments to DisplayGroup (DisplayGroup object) commands. The
    LeafFromConstraintNames object is derived from the Leaf object.

    .. note::
        This object can be accessed by::

            import displayGroupOdbToolset

    .. versionadded:: 2019
        The ``LeafFromConstraintNames`` class was added.
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are TIE,
    #: SHELL_TO_SOLID_COUPLING, DISTRIBUTING_COUPLING, KINEMATIC_COUPLING, RIGID_BODY, and MPC.
    leafType: SymbolicConstant

    @abaqus_method_doc
    def __init__(
        self,
        name: tuple,
        type: Literal[
            C.DISTRIBUTING_COUPLING, C.TIE, C.RIGID_BODY, C.MPC, C.SHELL_TO_SOLID_COUPLING, C.KINEMATIC_COUPLING
        ],
    ):
        """This method creates a Leaf object from a sequence of constraint objects. Leaf objects specify the
        items in a display group.

        .. note::
            This function can be accessed by::

                LeafFromConstraintNames

        Parameters
        ----------
        name
            A sequence of tuples of name objects.
        type
            A SymbolicConstant specifying the Leaf type. Possible values are TIE,
            SHELL_TO_SOLID_COUPLING, DISTRIBUTING_COUPLING, KINEMATIC_COUPLING, RIGID_BODY, and MPC.

        Returns
        -------
            A LeafFromConstraintNames object.
        """
        super().__init__(DEFAULT_MODEL)



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Profile import Profile


@abaqus_class_doc
class HatProfile(Profile):
    """The HatProfile object defines the properties of a hat profile. The HatProfile object
    is derived from the Profile object.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The corresponding analysis keywords are:

        - BEAM SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A positive Float specifying the l dimension (offset of 1–axis from the bottom flange surface) of the Hat
    #: profile. For more information, see Beam Cross-Section Library.
    l: float

    #: A positive Float specifying the h dimension (height) of the Hat profile.
    h: float

    #: A positive Float specifying the b dimension (bottom width) of the Hat profile.
    b: float

    #: A positive Float specifying the b1 dimension (upper flange width) of the Hat profile.
    b1: float

    #: A positive Float specifying the b2 dimension (lower flange width) of the Hat profile.
    b2: float

    #: A positive Float specifying the t1 dimension (upper flange thickness) of the Hat profile.
    t1: float

    #: A positive Float specifying the t2 dimension (lower flange thickness) of the Hat profile.
    t2: float

    #: A positive Float specifying the t3 dimension (web thickness) of the Hat profile.
    t3: float

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        l: float,
        h: float,
        b: float,
        b1: float,
        b2: float,
        t1: float,
        t2: float,
        t3: float,
    ):
        """This method creates a HatProfile object.

        .. note::
            This function can be accessed by::

                mdb.models[name].HatProfile
                session.odbs[name].HatProfile

        .. versionadded:: 2024

            The ``HatProfile`` class was added.

        Parameters
        ----------
        name
            A String specifying the repository key.
        l
            A positive Float specifying the l dimension (offset of 1–axis from the bottom flange surface) of the Hat
            profile. For more information, see Beam Cross-Section Library.
        h
            A positive Float specifying the h dimension (height) of the Hat profile.
        b
            A positive Float specifying the b dimension (bottom width) of the Hat profile.
        b1
            A positive Float specifying the b1 dimension (upper flange width) of the Hat profile.
        b2
            A positive Float specifying the b2 dimension (lower flange width) of the Hat profile.
        t1
            A positive Float specifying the t1 dimension (upper flange thickness) of the Hat profile.
        t2
            A positive Float specifying the t2 dimension (lower flange thickness) of the Hat profile.
        t3
            A positive Float specifying the t3 dimension (web thickness) of the Hat profile.

        Returns
        -------
        HatProfile
            An HatProfile object.

        Raises
        ------
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the HatProfile object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Profile import Profile


@abaqus_class_doc
class ChannelProfile(Profile):
    """The ChannelProfile object defines the properties of a channel profile. The ChannelProfile object
    is derived from the Profile object.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The corresponding analysis keywords are:

        - BEAM SECTION

    .. versionadded:: 2024
        The ``ChannelProfile`` class was added.
    """

    #: A String specifying the repository key.
    name: str

    #: A positive Float specifying the l dimension (offset of 1–axis from the bottom flange surface) of the Channel
    #: profile. For more information, see Beam Cross-Section Library.
    l: float

    #: A positive Float specifying the h dimension (height) of the Channel profile.
    h: float

    #: A positive Float specifying the b1 dimension (lower flange width) of the Channel profile.
    b1: float

    #: A positive Float specifying the b2 dimension (upper flange width) of the Channel profile.
    b2: float

    #: A positive Float specifying the t1 dimension (lower flange thickness) of the Channel profile.
    t1: float

    #: A positive Float specifying the t2 dimension (upper flange thickness) of the Channel profile.
    t2: float

    #: A positive Float specifying the t3 dimension (web thickness) of the Channel profile.
    t3: float

    #: A positive Float specifying the o dimension (offset of 2–axis from the left edge of web) of the Channel
    #: profile.
    o: float

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        l: float,
        h: float,
        b1: float,
        b2: float,
        t1: float,
        t2: float,
        t3: float,
        o: float,
    ):
        """This method creates a ChannelProfile object.

        .. note::
            This function can be accessed by::

                mdb.models[name].ChannelProfile
                session.odbs[name].ChannelProfile

        Parameters
        ----------
        name
            A String specifying the repository key.
        l
            A positive Float specifying the l dimension (offset of 1–axis from the bottom flange surface) of the Channel
            profile. For more information, see Beam Cross-Section Library.
        h
            A positive Float specifying the h dimension (height) of the Channel profile.
        b1
            A positive Float specifying the b1 dimension (lower flange width) of the Channel profile.
        b2
            A positive Float specifying the b2 dimension (upper flange width) of the Channel profile.
        t1
            A positive Float specifying the t1 dimension (lower flange thickness) of the Channel profile.
        t2
            A positive Float specifying the t2 dimension (upper flange thickness) of the Channel profile.
        t3
            A positive Float specifying the t3 dimension (web thickness) of the Channel profile.
        o
            A positive Float specifying the o dimension (offset of 2–axis from the left edge of web) of the Channel
            profile.

        Returns
        -------
        ChannelProfile
            An ChannelProfile object.

        Raises
        ------
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ChannelProfile object.

        Raises
        ------
        RangeError
        """
        ...
